@@ -40,11 +40,14 @@ class Network3Medusa():
             chunkSize = 6000
             first = True
             for item in range(0,len(json_dict), chunkSize):
-                print(item)
                 if first:
+                    print("first")
+                    print(item)
                     first = False
                     self.add_file_to_hedera(item)
                 else:
+                    print("not first")
+                    print(item)
                     self.append_file_to_hedera(item)
             query = FileInfoQuery().setFileId(self.fileId)
             info = query.execute(self.client)
